# JonahLint
*"I have had it with these monkey-fighting snakes on this Monday to Friday plane."* -
**Samuel L. Jackson**

You are a smart person. You know how to write code, and you know how to write it well.
You want your code to be clean. You are a clean person. You don't use profanities when
you talk to your mother, or to your boss. So why your code should?

*JonahLint* helps you to make sure that your code is clean from any profanities and bad
words. It lets you know exactly where the profanities appear in your code, and helps you
get rid of them quickly and thoroughly.

## Installation

Install *JonahLint* using:

```
pip install jonahlint
```

## Basic Usage

Run *JonahLint* using:

```
jonahlint <your_source_here> 
```

To see help instructions run:

```
jonahlint --help 
```

## But why "Jonah"?

You might not know that, but as of March 2021, the american actor Jonah Hill holds the
record for most profanities in motion picture films with [376 swear words in his entire
career](https://variety.com/2020/film/news/jonah-hill-most-swear-words-study-1234608621/).

Make your code Jonah-proof.

Use *JonahLint*.

**Disclaimer**: I'm a big fan of Jonah and his work.